@@ -19,6 +19,15 @@ impl Rgba32 {
         Self { r, g, b, a: 255 }
     }
 
+    pub const fn new_grey(x: u8) -> Self {
+        Self {
+            r: x,
+            g: x,
+            b: x,
+            a: 255,
+        }
+    }
+
     pub fn to_f32_array_01(self) -> [f32; 4] {
         [
             self.r as f32 / 255.,
@@ -28,3 +37,15 @@ impl Rgba32 {
         ]
     }
 }
+
+pub const fn rgba32(r: u8, g: u8, b: u8, a: u8) -> Rgba32 {
+    Rgba32::new(r, g, b, a)
+}
+
+pub const fn rgba32_rgb(r: u8, g: u8, b: u8) -> Rgba32 {
+    Rgba32::new_rgb(r, g, b)
+}
+
+pub const fn rgba32_grey(x: u8) -> Rgba32 {
+    Rgba32::new_grey(x)
+}
